from typing import List

from fastapi import FastAPI
from fastapi.responses import JSONResponse

from agix.qualia.qualia_core import EmotionalState
from agix.evaluation.metrics import EvaluationMetrics

app = FastAPI(title="AGIX Dashboard")

# Estado emocional global y registros de recompensa
emotional_state = EmotionalState()
reward_history: List[float] = []


def register_reward(reward: float) -> None:
    """Añade una recompensa al historial."""
    reward_history.append(float(reward))


def register_emotion(tipo: str, intensidad: float) -> None:
    """Registra una emoción en el estado global."""
    emotional_state.sentir(tipo, intensidad)


@app.get("/qualia")
def get_qualia():
    """Devuelve el estado emocional actual."""
    return JSONResponse(
        {
            "emociones": emotional_state.emociones,
            "tono": emotional_state.tono_general(),
        }
    )


@app.get("/metrics")
def get_metrics():
    """Calcula métricas básicas de aprendizaje."""
    return JSONResponse(
        {
            "average_reward": EvaluationMetrics.average_reward(reward_history),
            "max_reward": EvaluationMetrics.max_reward(reward_history),
            "std_reward": EvaluationMetrics.std_reward(reward_history),
            "success_rate": EvaluationMetrics.success_rate(reward_history),
        }
    )
